@@ -36,8 +36,8 @@ simple.violinplot.default <-
 
 
     ## work on the gropu by group level
-    xvals <- matrix(0,nr=512,nc=n)
-    yvals <- matrix(0,nr=512,nc=n)
+    xvals <- matrix(0,nrow=512,ncol=n)
+    yvals <- matrix(0,nrow=512,ncol=n)
     center<- 1:n                        # where are they centered
     for(i in 1:n) {
       if(is.null(from))
